==> haskell-boxes-0.1.5-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-5lh9oZIUuCXIZUXohXCOv4
key:                  boxes-0.1.5-5lh9oZIUuCXIZUXohXCOv4
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  2ea528c27665b4e1de177df3b0f38f60
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-8.10.2/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/boxes-0.1.5
hs-libraries:         HSboxes-0.1.5-5lh9oZIUuCXIZUXohXCOv4
depends:              base-4.14.1.0 split-0.2.3.4-EBC2l23lMaEIoWooJO0rmg
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boxes-0.1.5-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boxes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 boxes
version:              0.1.5
visibility:           public
id:                   boxes-0.1.5-JnogoOBVGSg3nx3joPErKg
key:                  boxes-0.1.5-JnogoOBVGSg3nx3joPErKg
license:              BSD-3-Clause
maintainer:           David Feuer <David.Feuer@gmail.com>
author:               Brent Yorgey
synopsis:             2D text pretty-printing library
description:
    A pretty-printing library for laying out text in
    two dimensions, using a simple box model.

category:             Text
abi:                  c17fea771111edad64f200330601df2d
exposed:              True
exposed-modules:      Text.PrettyPrint.Boxes
import-dirs:          /usr/lib/ghc-8.10.2/site-local/boxes-0.1.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/boxes-0.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/boxes-0.1.5
hs-libraries:         HSboxes-0.1.5-JnogoOBVGSg3nx3joPErKg
depends:              base-4.14.1.0 split-0.2.3.4-Ief2y9CxfKT8rhUpXhOBMg
haddock-interfaces:   /usr/share/doc/haskell-boxes/html/boxes.haddock
haddock-html:         /usr/share/doc/haskell-boxes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
